==> Acme-MetaSyntactic-Themes-1.000.tar.gz: Acme-MetaSyntactic-Themes-1.000/lib/Acme/MetaSyntactic/pasta.pm <==
package Acme::MetaSyntactic::pasta;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
our $VERSION = '1.000';
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::pasta - The pasta theme

=head1 DESCRIPTION

An incomplete list of Italian pasta names.

I love Italian food. Pasta is only a small part of it.

Some links:
L<http://www.italianpasta.net/pasta/tipi.htm>,
L<http://www.professionalpasta.it/>.

=head1 CONTRIBUTOR

Philippe "BooK" Bruhat.

Introduced in Acme-MetaSyntactic version 0.25, published on June 6, 2005.

Received its own version number for Acme-MetaSyntactic-Themes version 1.000,
published on May 7, 2012.

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
abissini
acini_de_pepe
agnoli
agnolini
agnolotti
alfabeto
amorini
amorosi
anchellini
anelletti
anelli
anelli_margherite_lisce
anellini
anellini_all_uovo
anellini_rigati
anelli_piatti
anelli_rigati
anelli_siciliani
angiulottus
anolini
armellette
armelline
armonie
arselle
arselloni
assabesi
astri
attorcigliati
avemarie
avemarie_lisce
avena
avena_grande
ave_storte_rigate
ballerine
barbina
barbine_a_nido
bardele
bassetti
bavette
bavette_fini
bavettine
bengasini
bifore
bigoli
bigui
blisgon
bocche_di_lupo
boccolotti
boccolotti_rigati
bombardoni
bombonini
bombonini_bucati
bricchetti
brofandei
bucatini
caciunilli
caicc
calzoncini
campanelle_rigate
canaloni
candele
canderli
canelloni_ripieni
canestri
canestri_all_uovo
canestrini
cannaroni
cannaroni_rigati
cannarozzi_rigati
cannellini
cannellini_piccoli
cannellini_rigati
cannelli_ziti
cannelloni
cannelloni_da_ripieno
cannelloni_ripieni
cannelloni_zitoni
canneroni
canneroni_grandi
canneroni_rigati
cannerozzoli
cannolicchi_grandi
cannolicchi_grandi_rigati
cannolicchi_medi
cannolicchi_medi_rigati
cannolicchi_piccoli
cannolicchi_piccoli_rigati
cannonciottini_festonati
cannonetti_rigati
canoncetti
canoncioni
canonciotti
cantaroggini
canutiglie
capelli_d_angelo
capelvenere
capiddi_di_angelo
capieddi_e_prevete
caporelli
cappe
cappellacci
cappelletti
cappellettini
cappelletti_umbri
cappellini
cappellini_a_matasse
cappellini_a_nido
cappellini_fini
cappello_napoletano
cappellotti
cappettine
caprette
capricciosa
capricciose
caramelle
cardinali
cardonelli
casarecce
casareccia_molisana
casonsei
casonsei_della_valcamonica
casonziei_bellunesi
castellane
cavatappi
cavatelli
cavatieddi
cavatielli
cavatoni
cavour
cellentani
cestini
chiancarelle
chicchi_di_riso
chifferi
chifferini
chifferini_lisci
chifferini_rigati
chifferi_rigati
chifferoni
chifferoni_rigati
chifferotti
chifferotti_rigati
chinesi
chiocciole
chioccioline
cialzons
ciancarelle
ciargnei
cicirata
cicorie
cicorietta
cimieri
cinesi
cinesini
cinesi_rigati
ciocchetti
cirilli
cirillini
ciriole
ciuffetti
ciuffolitti
cocce_rigate
cocciolette
coccioline
conchiglie
conchiglie_rigate
conchiglie_tricolore
conchigliette
conchiglioni
coppette
coralli
corallini
corallino_piccolo
cornetti
cornetti_di_cervo
cornetti_rigati
corni_di_bue
cortecce_nocelle
corzetti_alla_polceverasca
corzetti_stampati
cravatte
cravattine
creste
creste_di_gallo
crestine
crestine_rigate
crocette
crosetti
cudiddi
culingiones
culurjones
culurzones
cuoretti
cuoricini
damigella
dantesche
denti_di_cavallo
denti_di_cavallo_rigati
denti_di_pecora
denti_di_pecora_rigati
diavoletti
diavoletti_rigati
diavolini
dischi
dischi_volanti
ditaletti
ditali
ditali_di_zitoni
ditali_lisci
ditalini
ditalini_lisci
ditalini_rigati
ditali_rigati
ditaloni
doppio_zero
dura
elefante
eliche
eliche_grandi
elichette
elicoidali
fagioletti
fagioli
fagiolini
fagiolini_rigati
fagioloni
fagioloni_rigati
farfalle
farfalle_genovesi
farfalle_tonde
farfalle_tricolore
farfallette
farfalline
farfalloni
fedelini
fenescecchie
ferri_di_cavallo
festonati
fettucce
fettucce_all_uovo
fettucce_a_nido
fettuccelle
fettuccelle_ricce
fettucce_ricce
fettucce_romane
fettuccia_riccia
fettuccine
fettuccine_a_nido
fettuccine_rosse
fettuccine_verdi
fiadi
fiammiferini
fiandoncelli
fide
fide_bucate
fideline_a_matasse
fidelini
fidelini_all_uovo
fidelini_a_matassa
fidelini_bucati
fideos
fieno
filatelli
filini_all_uovo
filograna
fiocchetti
fiocchi_d_amore
fiocchini
fiocconi
fiore
fiori_di_sambuco
fischioni
fischioni_rigati
fischiotti
fischiotti_rigati
folletti
follettini
foratini
francesine
fregolina
fregula
frese
fresine
fujade
fulminanti
funghetti
funghini
fusilli
fusilli_a_tre_alette
fusilli_a_spirale
fusilli_corti_bucati
fusilli_forati
fusilli_giganti
fusilli_lunghi
fusilli_molle
fusilli_rigati
fusilli_tricolore
fusillo
fusilloni
fusilloni_col_buco
galani
galla_genovese
galla_mezzana
garganelli
gargherozzini
gemelli
genovesini
gianduietta
gianduini
giganti
gigantoni
gigli
giostre
girini
gnocchetti
gnocchetti_di_ziti
gnocchetti_di_ziti_lunghi_rigati
gnocchettini
gnocchetti_rigati
gnocchetti_sardi
gnocchetti_ziti
gnocchettoni_zitoni
gnocchi
gnocchi_alla_romana
gobbein
gobbetti
gobbini
gobboni
gomiti
gomitini
gomiti_rigati
gozzetti
gozzettoni
gozzini
gramigna
gramigna_piena
gramigna_rigata
gramignino_liscio
gramignino_rigato
gramignoni
gramignoni_rigati
grandine
grandine_bucata
grandinina_soda
grano
grattata
grattini
grattoni
grosso_rigato
guanti
ideogrammi
italiana
labirinto
lacchene
lagane
laganelle
laianelle
lancette
lancine
lasagna
lasagne
lasagne_all_uovo
lasagne_doppio_festone
lasagne_festonate
lasagne_festonate_a_nidi
lasagne_grandi
lasagne_inferrigne
lasagne_piccole
lasagne_ricce
lasagnette
lasagnette_doppio_riccio
lasagnette_nido
lasagnette_ricce
lasagne_verdi
lasagnoni
lentigette
lentine
lingue_di_passero
linguettine
linguine
linguine_all_uovo
linguine_a_matasse
linguine_a_nido
linguinette
lucciole
lumache
lumache_grandi
lumachelle
lumachelle_rigate
lumache_rigate
lumachette
lumachine
lumachine_rigate
lumaconi
lumaconi_rigati
macaron_chi_fir
macaroni
macarrao
maccaroni
maccaruna_di_casa
maccaruni_ciociari
maccheroncelli
maccheroncini
maccheroni
maccheroni_a_ferritus
maccheroni_alla_molinara
maccheroni_al_rintrocilo
maccheroni_al_torchio
maccheroni_bobbiesi
maccheroni_della_ceppa
maccheroni_inferrettati
mafalde
mafaldine
maglietta
malfatti
malfattini
malloreddus
maltagliati
maltagliati_grossi
mandilli_de_sea
manfattini
manfettini
manfredi
manfredine
manfricoli
manfroni
maniche
maniche_centorighe
maniche_rigate
margaritine
margherita_messinese_lunga
margherite
margherite_lisce
margherite_rigate
margheritine
marubini
maruzze
marziani
merletti
messicani
messinesi
mezzanelli
mezzanelli_rigati
mezzanelli_tagliati
mezzani
mezze_cocciolette
mezze_lasagne
mezze_lasagne_ricce
mezze_maniche
mezze_maniche_rigate
mezze_penne
mezze_penne_mezzani
mezze_penne_rigate
mezze_pennette_lisce
mezze_penne_zita
mezze_pipe
mezze_zite
mezze_zite_tagliate
mezzi_cannaroni
mezzi_cocci
mezzi_gnocchetti
mezzi_gomiti
mezzi_occhi_di_lupo
mezzi_rigatoni
mezzi_tufoli
mezzi_vermicelli
midolline
militari
millerighe
minuicchi
minuscole
mista
mostaccioli
mostaccioli_rigati
mughetto
napellini_rigati
napoleone
napoletani
nastri
nastri_doppio_festone
nastrini
natalini
nicchiole
nidi
nocche
nocchettine
nocciole
noccioline
noccioloni
nodi
nodini
nudeln
nuvole
occhialini
occhi_di_bove
occhi_di_elefante
occhi_di_giudeo
occhi_di_lupo
occhi_di_lupo_rigati
occhi_di_passero
occhi_di_pernice
occhi_di_trota
occhio_d_aquila
ombrelle
ondine
ondule
orecchie_di_giudeo
orecchiette
orecchiette_baresi
orecchiette_pugliesi
orecchioni
orzo
paccheri
paccheri_lisci
padrenosso
paglia_e_fieno
pagliafieno_all_uovo
palloncino
pancit
panierine
pansotti_al_preboggion
pantacce
panzerotti
pappallegri
pappardelle
pappardelle_all_uovo
papparelle
parigine
parpadellini
passamontagna
pasta_alla_chitarra
pasta_alla_molinara
pasta_busiata
pasta_grattata
pasta_reale
paternoster
pelmeni
penna_a_candela
penna_a_candela_rigate
penne
penne_di_mezzani
penne_di_mezzani_rigate
penne_di_natale
penne_di_ziti
penne_di_ziti_rigate
penne_di_zitoni
penne_di_zitoni_rigate
penne_lisce
penne_margherita
penne_regina
penne_regina_rigate
penne_rigate
penne_senza_glutine
pennette
pennette_rigate
pennettine
pennettine_lisce
pennettine_rigate
penne_ziti
penne_zitoni
pennine
pennine_lisce
pennine_rigate
pennini
pennoni
pennoni_rigati
pennuzze
pennuzze_rigate
pepe
pepe_bucato
peperini_bucati
peperini_di_genova
peperino
perciatelli
perciatellini
perciatelloni
perline
pernicette
pernicettine
pestazzule
piccagge
picchiettini
pici
pinci
pincinelli
piombi
pipe
pipe_rigate
pipette
pisarei
piselli
pisellini
pizzelle
pizzicotti
pizzoccheri
pociacche
primaverine
primerini
puffi
pulcini
puntalette
punte_d_ago
puntine
quadratini
quadretti
quadretti_all_uovo
quadrettini
quadrettone
quadrucci
quadruccini_trinati
quadrucci_rigati
radiatori
radichini
rafioli
ravioli
ravioli_abruzzesi
raviolini
ravioloni
recchie
rechietelle
regine
reginella_a_matassa
reginelle
reginelle_a_nido
reginelle_corte
reginette
reginette_a_nido
ricciarelle
riccioli
riccioli_di_sfoglia
riccioline
ricciutelle
ricciutelli
rice_vermicelli
ricurvi
rigatoncini
rigatoni
rigatoni_romani
risetto
riso
riso_all_uovo
risone
ristoranti
rocchetti
roletti
roselline
rotelle
rotelline
rotine
rotini
ruote
ruotine
salamini
salatielli
saliere
scalette
scaloppi
schiaffoni
sciablo
sciabo
sciliatelli
scintille
scivateddi
sciviottini
sciviottini_rigati
sciviotti_ziti
sciviotti_ziti_rigati
sciviotti_zitoni
sciviotti_zitoni_rigati
scodelle
scodelline
sedanetti
sedanetti_rigati
sedani_corti
sedani_lisci
sedani_lisci_grossi
sedani_margherita_rigati
sedanini
sedanini_lisci
sedanini_rigati
sedani_rigati
sementine
seme_santo
semi_d_avena
semi_di_cicoria
semi_di_mela
semi_di_melone
semi_di_peperone
semi_di_riso
semi_di_rosmarino
semi_d_orzo
semini
semolino
semoni
settebuchi
sfresatine
sguazzarotti
sigarette
signorine
signorine_a_nido
somen
sopracappellini
sorprese
sorpresine
spaccatelle
spaghetti
spaghetti_alla_chitarra
spaghettini
spaghettini_a_nocchette
spaghettini_in_matasse
spaghettoni
spiedini
spiganarda
spighe
spira
spirali
spole
spolette
stelle
stellette
stellettine
stelline
stelloni
stivalettini
stivalettini_rigati
stortelli
stortini
stortini_rigati
stortoni
strangolapreti
strascenate
strascinari
strascinati
strascinati_chiusi
strengozze
stricchetti
stricchetti_bolognesi
stricchetti_tondi
strichetti
stringozzi
svoltini
svuotini
svuotini_rigati
tacconelli
tacconi
taccozze
taccozze_de_muline
tagliarelli
tagliarellini
tagliatelle
tagliatelle_all_uovo
tagliatelle_a_matasse
tagliatelle_a_nido
tagliatelle_grandi_a_nido
tagliatelle_larghe
tagliatelle_nervate
tagliatelle_piccole_a_matasse
tagliatelle_piccole_a_nido
tagliatelle_verdi
tagliatelline
tagliati_di_mezzani
tagliati_di_ziti
tagliati_di_zitoni
taglierini_all_uovo
tagliolini
tagliolini_all_uovo
tagliolini_a_nido
tajarin
tallarines
telline
tempesta
tempestina
tofarelle
tofettine
torciglioni
torcinelli
tordelli
tortelli
tortelli_alla_cremasca
tortelli_della_vigilia
tortelli_di_zucca
tortellini
tortelli_toscani
tortelloni
tortelloni_alla_valdostana
tortigli
tortiglietti
tortiglioni
tortiglioni_grandi
tortini
trenette
trenette_avvantaggiate
trifogli
trinette
trinette_a_matasse
trinette_a_nido
tripoline
tripoline_a_punta
tripoline_trinate
tripolini
tripolini_a_nochette
trivelle
trivelli
trivellini
troccoli
trofie
trofiette_rechelline
trombette
trottole
tubetti
tubetti_lunghi
tubetti_lunghi_rigati
tubettini
tubettini_lunghi
tufoli
tufoli_rigati
turbanti
turbantini
turtei_cu_la_cua
turtlo
u_cazini
umbricelli
umbrici
vaporino
vermicelli
vermicellini
vermicelloni
vermicelloni_giganti
vuocche_e_vecchia
zero
zite
zitellini
zitello
ziti
ziti_tagliati
ziti_tagliati_rigati
zitoni
zitoni_tagliati
zitoni_tagliati_rigati
zituane
zuarini

==> Acme-MetaSyntactic-Themes-1.046.tar.gz: Acme-MetaSyntactic-Themes-1.046/lib/Acme/MetaSyntactic/pasta.pm <==
package Acme::MetaSyntactic::pasta;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
our $VERSION = '1.000';
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::pasta - The pasta theme

=head1 DESCRIPTION

An incomplete list of Italian pasta names.

I love Italian food. Pasta is only a small part of it.

Some links:
L<http://www.italianpasta.net/pasta/tipi.htm>,
L<http://www.professionalpasta.it/>.

=head1 CONTRIBUTOR

Philippe "BooK" Bruhat.

=head1 CHANGES

=over 4

=item *

2012-05-07 - v1.000

Received its own version number in Acme-MetaSyntactic-Themes version 1.000.

=item *

2005-06-06

Introduced in Acme-MetaSyntactic version 0.25.

=back

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
abissini
acini_de_pepe
agnoli
agnolini
agnolotti
alfabeto
amorini
amorosi
anchellini
anelletti
anelli
anelli_margherite_lisce
anellini
anellini_all_uovo
anellini_rigati
anelli_piatti
anelli_rigati
anelli_siciliani
angiulottus
anolini
armellette
armelline
armonie
arselle
arselloni
assabesi
astri
attorcigliati
avemarie
avemarie_lisce
avena
avena_grande
ave_storte_rigate
ballerine
barbina
barbine_a_nido
bardele
bassetti
bavette
bavette_fini
bavettine
bengasini
bifore
bigoli
bigui
blisgon
bocche_di_lupo
boccolotti
boccolotti_rigati
bombardoni
bombonini
bombonini_bucati
bricchetti
brofandei
bucatini
caciunilli
caicc
calzoncini
campanelle_rigate
canaloni
candele
canderli
canelloni_ripieni
canestri
canestri_all_uovo
canestrini
cannaroni
cannaroni_rigati
cannarozzi_rigati
cannellini
cannellini_piccoli
cannellini_rigati
cannelli_ziti
cannelloni
cannelloni_da_ripieno
cannelloni_ripieni
cannelloni_zitoni
canneroni
canneroni_grandi
canneroni_rigati
cannerozzoli
cannolicchi_grandi
cannolicchi_grandi_rigati
cannolicchi_medi
cannolicchi_medi_rigati
cannolicchi_piccoli
cannolicchi_piccoli_rigati
cannonciottini_festonati
cannonetti_rigati
canoncetti
canoncioni
canonciotti
cantaroggini
canutiglie
capelli_d_angelo
capelvenere
capiddi_di_angelo
capieddi_e_prevete
caporelli
cappe
cappellacci
cappelletti
cappellettini
cappelletti_umbri
cappellini
cappellini_a_matasse
cappellini_a_nido
cappellini_fini
cappello_napoletano
cappellotti
cappettine
caprette
capricciosa
capricciose
caramelle
cardinali
cardonelli
casarecce
casareccia_molisana
casonsei
casonsei_della_valcamonica
casonziei_bellunesi
castellane
cavatappi
cavatelli
cavatieddi
cavatielli
cavatoni
cavour
cellentani
cestini
chiancarelle
chicchi_di_riso
chifferi
chifferini
chifferini_lisci
chifferini_rigati
chifferi_rigati
chifferoni
chifferoni_rigati
chifferotti
chifferotti_rigati
chinesi
chiocciole
chioccioline
cialzons
ciancarelle
ciargnei
cicirata
cicorie
cicorietta
cimieri
cinesi
cinesini
cinesi_rigati
ciocchetti
cirilli
cirillini
ciriole
ciuffetti
ciuffolitti
cocce_rigate
cocciolette
coccioline
conchiglie
conchiglie_rigate
conchiglie_tricolore
conchigliette
conchiglioni
coppette
coralli
corallini
corallino_piccolo
cornetti
cornetti_di_cervo
cornetti_rigati
corni_di_bue
cortecce_nocelle
corzetti_alla_polceverasca
corzetti_stampati
cravatte
cravattine
creste
creste_di_gallo
crestine
crestine_rigate
crocette
crosetti
cudiddi
culingiones
culurjones
culurzones
cuoretti
cuoricini
damigella
dantesche
denti_di_cavallo
denti_di_cavallo_rigati
denti_di_pecora
denti_di_pecora_rigati
diavoletti
diavoletti_rigati
diavolini
dischi
dischi_volanti
ditaletti
ditali
ditali_di_zitoni
ditali_lisci
ditalini
ditalini_lisci
ditalini_rigati
ditali_rigati
ditaloni
doppio_zero
dura
elefante
eliche
eliche_grandi
elichette
elicoidali
fagioletti
fagioli
fagiolini
fagiolini_rigati
fagioloni
fagioloni_rigati
farfalle
farfalle_genovesi
farfalle_tonde
farfalle_tricolore
farfallette
farfalline
farfalloni
fedelini
fenescecchie
ferri_di_cavallo
festonati
fettucce
fettucce_all_uovo
fettucce_a_nido
fettuccelle
fettuccelle_ricce
fettucce_ricce
fettucce_romane
fettuccia_riccia
fettuccine
fettuccine_a_nido
fettuccine_rosse
fettuccine_verdi
fiadi
fiammiferini
fiandoncelli
fide
fide_bucate
fideline_a_matasse
fidelini
fidelini_all_uovo
fidelini_a_matassa
fidelini_bucati
fideos
fieno
filatelli
filini_all_uovo
filograna
fiocchetti
fiocchi_d_amore
fiocchini
fiocconi
fiore
fiori_di_sambuco
fischioni
fischioni_rigati
fischiotti
fischiotti_rigati
folletti
follettini
foratini
francesine
fregolina
fregula
frese
fresine
fujade
fulminanti
funghetti
funghini
fusilli
fusilli_a_tre_alette
fusilli_a_spirale
fusilli_corti_bucati
fusilli_forati
fusilli_giganti
fusilli_lunghi
fusilli_molle
fusilli_rigati
fusilli_tricolore
fusillo
fusilloni
fusilloni_col_buco
galani
galla_genovese
galla_mezzana
garganelli
gargherozzini
gemelli
genovesini
gianduietta
gianduini
giganti
gigantoni
gigli
giostre
girini
gnocchetti
gnocchetti_di_ziti
gnocchetti_di_ziti_lunghi_rigati
gnocchettini
gnocchetti_rigati
gnocchetti_sardi
gnocchetti_ziti
gnocchettoni_zitoni
gnocchi
gnocchi_alla_romana
gobbein
gobbetti
gobbini
gobboni
gomiti
gomitini
gomiti_rigati
gozzetti
gozzettoni
gozzini
gramigna
gramigna_piena
gramigna_rigata
gramignino_liscio
gramignino_rigato
gramignoni
gramignoni_rigati
grandine
grandine_bucata
grandinina_soda
grano
grattata
grattini
grattoni
grosso_rigato
guanti
ideogrammi
italiana
labirinto
lacchene
lagane
laganelle
laianelle
lancette
lancine
lasagna
lasagne
lasagne_all_uovo
lasagne_doppio_festone
lasagne_festonate
lasagne_festonate_a_nidi
lasagne_grandi
lasagne_inferrigne
lasagne_piccole
lasagne_ricce
lasagnette
lasagnette_doppio_riccio
lasagnette_nido
lasagnette_ricce
lasagne_verdi
lasagnoni
lentigette
lentine
lingue_di_passero
linguettine
linguine
linguine_all_uovo
linguine_a_matasse
linguine_a_nido
linguinette
lucciole
lumache
lumache_grandi
lumachelle
lumachelle_rigate
lumache_rigate
lumachette
lumachine
lumachine_rigate
lumaconi
lumaconi_rigati
macaron_chi_fir
macaroni
macarrao
maccaroni
maccaruna_di_casa
maccaruni_ciociari
maccheroncelli
maccheroncini
maccheroni
maccheroni_a_ferritus
maccheroni_alla_molinara
maccheroni_al_rintrocilo
maccheroni_al_torchio
maccheroni_bobbiesi
maccheroni_della_ceppa
maccheroni_inferrettati
mafalde
mafaldine
maglietta
malfatti
malfattini
malloreddus
maltagliati
maltagliati_grossi
mandilli_de_sea
manfattini
manfettini
manfredi
manfredine
manfricoli
manfroni
maniche
maniche_centorighe
maniche_rigate
margaritine
margherita_messinese_lunga
margherite
margherite_lisce
margherite_rigate
margheritine
marubini
maruzze
marziani
merletti
messicani
messinesi
mezzanelli
mezzanelli_rigati
mezzanelli_tagliati
mezzani
mezze_cocciolette
mezze_lasagne
mezze_lasagne_ricce
mezze_maniche
mezze_maniche_rigate
mezze_penne
mezze_penne_mezzani
mezze_penne_rigate
mezze_pennette_lisce
mezze_penne_zita
mezze_pipe
mezze_zite
mezze_zite_tagliate
mezzi_cannaroni
mezzi_cocci
mezzi_gnocchetti
mezzi_gomiti
mezzi_occhi_di_lupo
mezzi_rigatoni
mezzi_tufoli
mezzi_vermicelli
midolline
militari
millerighe
minuicchi
minuscole
mista
mostaccioli
mostaccioli_rigati
mughetto
napellini_rigati
napoleone
napoletani
nastri
nastri_doppio_festone
nastrini
natalini
nicchiole
nidi
nocche
nocchettine
nocciole
noccioline
noccioloni
nodi
nodini
nudeln
nuvole
occhialini
occhi_di_bove
occhi_di_elefante
occhi_di_giudeo
occhi_di_lupo
occhi_di_lupo_rigati
occhi_di_passero
occhi_di_pernice
occhi_di_trota
occhio_d_aquila
ombrelle
ondine
ondule
orecchie_di_giudeo
orecchiette
orecchiette_baresi
orecchiette_pugliesi
orecchioni
orzo
paccheri
paccheri_lisci
padrenosso
paglia_e_fieno
pagliafieno_all_uovo
palloncino
pancit
panierine
pansotti_al_preboggion
pantacce
panzerotti
pappallegri
pappardelle
pappardelle_all_uovo
papparelle
parigine
parpadellini
passamontagna
pasta_alla_chitarra
pasta_alla_molinara
pasta_busiata
pasta_grattata
pasta_reale
paternoster
pelmeni
penna_a_candela
penna_a_candela_rigate
penne
penne_di_mezzani
penne_di_mezzani_rigate
penne_di_natale
penne_di_ziti
penne_di_ziti_rigate
penne_di_zitoni
penne_di_zitoni_rigate
penne_lisce
penne_margherita
penne_regina
penne_regina_rigate
penne_rigate
penne_senza_glutine
pennette
pennette_rigate
pennettine
pennettine_lisce
pennettine_rigate
penne_ziti
penne_zitoni
pennine
pennine_lisce
pennine_rigate
pennini
pennoni
pennoni_rigati
pennuzze
pennuzze_rigate
pepe
pepe_bucato
peperini_bucati
peperini_di_genova
peperino
perciatelli
perciatellini
perciatelloni
perline
pernicette
pernicettine
pestazzule
piccagge
picchiettini
pici
pinci
pincinelli
piombi
pipe
pipe_rigate
pipette
pisarei
piselli
pisellini
pizzelle
pizzicotti
pizzoccheri
pociacche
primaverine
primerini
puffi
pulcini
puntalette
punte_d_ago
puntine
quadratini
quadretti
quadretti_all_uovo
quadrettini
quadrettone
quadrucci
quadruccini_trinati
quadrucci_rigati
radiatori
radichini
rafioli
ravioli
ravioli_abruzzesi
raviolini
ravioloni
recchie
rechietelle
regine
reginella_a_matassa
reginelle
reginelle_a_nido
reginelle_corte
reginette
reginette_a_nido
ricciarelle
riccioli
riccioli_di_sfoglia
riccioline
ricciutelle
ricciutelli
rice_vermicelli
ricurvi
rigatoncini
rigatoni
rigatoni_romani
risetto
riso
riso_all_uovo
risone
ristoranti
rocchetti
roletti
roselline
rotelle
rotelline
rotine
rotini
ruote
ruotine
salamini
salatielli
saliere
scalette
scaloppi
schiaffoni
sciablo
sciabo
sciliatelli
scintille
scivateddi
sciviottini
sciviottini_rigati
sciviotti_ziti
sciviotti_ziti_rigati
sciviotti_zitoni
sciviotti_zitoni_rigati
scodelle
scodelline
sedanetti
sedanetti_rigati
sedani_corti
sedani_lisci
sedani_lisci_grossi
sedani_margherita_rigati
sedanini
sedanini_lisci
sedanini_rigati
sedani_rigati
sementine
seme_santo
semi_d_avena
semi_di_cicoria
semi_di_mela
semi_di_melone
semi_di_peperone
semi_di_riso
semi_di_rosmarino
semi_d_orzo
semini
semolino
semoni
settebuchi
sfresatine
sguazzarotti
sigarette
signorine
signorine_a_nido
somen
sopracappellini
sorprese
sorpresine
spaccatelle
spaghetti
spaghetti_alla_chitarra
spaghettini
spaghettini_a_nocchette
spaghettini_in_matasse
spaghettoni
spiedini
spiganarda
spighe
spira
spirali
spole
spolette
stelle
stellette
stellettine
stelline
stelloni
stivalettini
stivalettini_rigati
stortelli
stortini
stortini_rigati
stortoni
strangolapreti
strascenate
strascinari
strascinati
strascinati_chiusi
strengozze
stricchetti
stricchetti_bolognesi
stricchetti_tondi
strichetti
stringozzi
svoltini
svuotini
svuotini_rigati
tacconelli
tacconi
taccozze
taccozze_de_muline
tagliarelli
tagliarellini
tagliatelle
tagliatelle_all_uovo
tagliatelle_a_matasse
tagliatelle_a_nido
tagliatelle_grandi_a_nido
tagliatelle_larghe
tagliatelle_nervate
tagliatelle_piccole_a_matasse
tagliatelle_piccole_a_nido
tagliatelle_verdi
tagliatelline
tagliati_di_mezzani
tagliati_di_ziti
tagliati_di_zitoni
taglierini_all_uovo
tagliolini
tagliolini_all_uovo
tagliolini_a_nido
tajarin
tallarines
telline
tempesta
tempestina
tofarelle
tofettine
torciglioni
torcinelli
tordelli
tortelli
tortelli_alla_cremasca
tortelli_della_vigilia
tortelli_di_zucca
tortellini
tortelli_toscani
tortelloni
tortelloni_alla_valdostana
tortigli
tortiglietti
tortiglioni
tortiglioni_grandi
tortini
trenette
trenette_avvantaggiate
trifogli
trinette
trinette_a_matasse
trinette_a_nido
tripoline
tripoline_a_punta
tripoline_trinate
tripolini
tripolini_a_nochette
trivelle
trivelli
trivellini
troccoli
trofie
trofiette_rechelline
trombette
trottole
tubetti
tubetti_lunghi
tubetti_lunghi_rigati
tubettini
tubettini_lunghi
tufoli
tufoli_rigati
turbanti
turbantini
turtei_cu_la_cua
turtlo
u_cazini
umbricelli
umbrici
vaporino
vermicelli
vermicellini
vermicelloni
vermicelloni_giganti
vuocche_e_vecchia
zero
zite
zitellini
zitello
ziti
ziti_tagliati
ziti_tagliati_rigati
zitoni
zitoni_tagliati
zitoni_tagliati_rigati
zituane
zuarini
